@@ -208,7 +208,7 @@ def init_dwi_finalize_wf(scan_groups,
             'fieldwarps',
             'output_grid',
             'sbref_file', 'subjects_dir', 'subject_id',
-            't1_preproc', 't1_brain', 't1_mask', 'mni_mask', 't1_seg', 't1_tpms',
+            't1_preproc', 't1_brain', 't1_mask', 't1_seg', 't1_tpms',
             't1_aseg', 't1_aparc',
             't1_2_mni_reverse_transform', 't1_2_fsnative_forward_transform',
             't1_2_fsnative_reverse_transform', 'dwi_sampling_grid', 'raw_qc_file',
@@ -218,9 +218,7 @@ def init_dwi_finalize_wf(scan_groups,
     outputnode = pe.Node(
         niu.IdentityInterface(fields=[
             'dwi_t1', 'dwi_mask_t1', 'cnr_map_t1', 'bvals_t1', 'bvecs_t1', 'local_bvecs_t1',
-            't1_b0_ref', 'dwi_mni', 'dwi_mask_mni', 'cnr_map_mni', 'bvals_mni',
-            'bvecs_mni', 'local_bvecs_mni', 'mni_b0_ref', 'confounds',
-            'gradient_table_mni', 'gradient_table_t1', 'hmc_optimization_data'
+            't1_b0_ref', 'confounds', 'gradient_table_t1', 'hmc_optimization_data'
         ]),
         name='outputnode')
 
@@ -248,7 +246,6 @@ def init_dwi_finalize_wf(scan_groups,
                                           to_mni=False,
                                           write_local_bvecs=write_local_bvecs,
                                           concatenate=write_derivatives)
-    interactive_report_wf = init_interactive_report_wf()
 
     workflow.connect([
         (inputnode, transform_dwis_t1, [
@@ -278,7 +275,25 @@ def init_dwi_finalize_wf(scan_groups,
                                          ('outputnode.b0_series', 't1_b0_series'),
                                          ('outputnode.dwi_ref_resampled', 't1_b0_ref'),
                                          ('outputnode.resampled_dwi_mask', 'dwi_mask_t1'),
-                                         ('outputnode.resampled_qc', 'series_qc_t1')]),
+                                         ('outputnode.resampled_qc', 'series_qc_t1')])
+    ])
+
+    # Fill-in datasinks of reportlets seen so far
+    for node in workflow.list_node_names():
+        if node.split('.')[-1].startswith('ds_report'):
+            workflow.get_node(node).inputs.base_directory = reportlets_dir
+            workflow.get_node(node).inputs.source_file = source_file
+
+    # The workflow is done if we will be concatenating images later
+    if not write_derivatives:
+        # The list of transformed images is already attached to dwi_t1
+        return workflow
+
+    # Finish up the derivatives process
+    interactive_report_wf = init_interactive_report_wf()
+
+    # We need to attach outputs to the interactive report
+    workflow.connect([
         (inputnode, interactive_report_wf, [
             ('raw_concatenated', 'inputnode.raw_dwi_file'),
             ('carpetplot_data', 'inputnode.carpetplot_data'),
@@ -291,16 +306,6 @@ def init_dwi_finalize_wf(scan_groups,
         (interactive_report_wf, outputnode, [('outputnode.out_report', 'interactive_report')])
     ])
 
-    # Fill-in datasinks of reportlets seen so far
-    for node in workflow.list_node_names():
-        if node.split('.')[-1].startswith('ds_report'):
-            workflow.get_node(node).inputs.base_directory = reportlets_dir
-            workflow.get_node(node).inputs.source_file = source_file
-
-    if not write_derivatives:
-        # The list of transformed images is already attached to dwi_t1
-        return workflow
-
     # CONNECT TO DERIVATIVES #####################
     gtab_t1 = pe.Node(MRTrixGradientTable(), name='gtab_t1')
     t1_dice_calc = init_mask_overlap_wf(name='t1_dice_calc')
@@ -372,14 +377,6 @@ def init_dwi_finalize_wf(scan_groups,
           ('local_bvecs_t1', 'inputnode.local_bvecs_t1'),
           ('t1_b0_ref', 'inputnode.t1_b0_ref'),
           ('gradient_table_t1', 'inputnode.gradient_table_t1'),
-          ('dwi_mni', 'inputnode.dwi_mni'),
-          ('dwi_mask_mni', 'inputnode.dwi_mask_mni'),
-          ('cnr_map_mni', 'inputnode.cnr_map_mni'),
-          ('bvals_mni', 'inputnode.bvals_mni'),
-          ('bvecs_mni', 'inputnode.bvecs_mni'),
-          ('local_bvecs_mni', 'inputnode.local_bvecs_mni'),
-          ('mni_b0_ref', 'inputnode.mni_b0_ref'),
-          ('gradient_table_mni', 'inputnode.gradient_table_mni'),
           ('confounds', 'inputnode.confounds'),
           ('hmc_optimization_data', 'inputnode.hmc_optimization_data')]),
         (inputnode, gradient_plot, [
