@@ -2,6 +2,13 @@
 MRTrix workflows
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
+Note that in nipype interfaces the threading-controlling attribute is 
+``nthreads``, not the typical ``num_threads`` expected by nipype. 
+To keep threading consistent between nipype and mrtrix, the 
+``nthreads`` attribute needs to be set in the interface and the 
+``n_procs`` attribute needs to be set on the Node.
+
+
 .. autofunction:: init_mrtrix_csd_recon_wf
 
 """
@@ -77,22 +84,20 @@ def init_mrtrix_csd_recon_wf(omp_nthreads, available_anatomical_data, name="mrtr
 
 
     """
-    inputnode = pe.Node(niu.IdentityInterface(fields=recon_workflow_input_fields + ['odf_rois']),
-                        name="inputnode")
+    inputnode = pe.Node(
+        niu.IdentityInterface(fields=recon_workflow_input_fields),
+        name="inputnode")
     outputnode = pe.Node(
         niu.IdentityInterface(
             fields=['fod_sh_mif', 'wm_odf', 'wm_txt', 'gm_odf', 'gm_txt', 'csf_odf',
                     'csf_txt']),
         name="outputnode")
     workflow = Workflow(name=name)
+    plot_reports = params.pop("plot_reports", True)
     desc = """MRtrix3 Reconstruction
 
 : """
 
-    # Resample anat mask
-    resample_mask = pe.Node(
-        afni.Resample(outputtype='NIFTI_GZ', resample_mode="NN"), name='resample_mask')
-
     # Response estimation
     response = params.get('response', {})
     response_algorithm = response.get('algorithm', 'dhollander')
@@ -120,6 +125,7 @@ FODs were estimated via constrained spherical deconvolution
     fod_algorithm = fod.get('algorithm', 'msmt_csd')
     fod['algorithm'] = fod_algorithm
     fod['nthreads'] = omp_nthreads
+    LOGGER.info("Using %d threads in MRtrix3", omp_nthreads)
     using_multitissue = fod_algorithm in ('ss3t', 'msmt_csd')
 
     # Intensity normalize?
@@ -128,7 +134,10 @@ FODs were estimated via constrained spherical deconvolution
     create_mif = pe.Node(MRTrixIngress(), name='create_mif')
     method_5tt = response.pop("method_5tt", "fast")
     # Use dwi2response from 3Tissue for updated dhollander
-    estimate_response = pe.Node(SS3TDwi2Response(**response), 'estimate_response')
+    estimate_response = pe.Node(
+        SS3TDwi2Response(**response), 
+        name='estimate_response',
+        n_procs=omp_nthreads)
 
     if response_algorithm == 'msmt_5tt':
         if method_5tt == "hsvs":
@@ -141,55 +150,36 @@ FODs were estimated via constrained spherical deconvolution
             raise Exception("Unrecognized 5tt method: " + method_5tt)
 
     if fod_algorithm in ('msmt_csd', 'csd'):
-        estimate_fod = pe.Node(EstimateFOD(**fod), 'estimate_fod')
+        estimate_fod = pe.Node(
+            EstimateFOD(**fod), 
+            name='estimate_fod',
+            n_procs=omp_nthreads)
         desc += ' Reconstruction was done using MRtrix3 (@mrtrix3).'
     elif fod_algorithm == 'ss3t':
-        estimate_fod = pe.Node(SS3TEstimateFOD(**fod), 'estimate_fod')
+        estimate_fod = pe.Node(
+            SS3TEstimateFOD(**fod), 
+            name='estimate_fod',
+            n_procs=omp_nthreads)
         desc += """ \
 A single-shell-optimized multi-tissue CSD was performed using MRtrix3Tissue
 (https://3Tissue.github.io), a fork of MRtrix3 (@mrtrix3)"""
 
-    # Make a visual report of the model
-    plot_peaks = pe.Node(CLIReconPeaksReport(), name='plot_peaks')
-    ds_report_peaks = pe.Node(
-        ReconDerivativesDataSink(extension='.png',
-                                 desc="wmFOD",
-                                 suffix='peaks'),
-        name='ds_report_peaks',
-        run_without_submitting=True)
-
-    # Plot targeted regions
-    if available_anatomical_data['has_qsiprep_t1w_transforms']:
-        ds_report_odfs = pe.Node(
-            ReconDerivativesDataSink(extension='.png',
-                                     desc="wmFOD",
-                                     suffix='odfs'),
-            name='ds_report_odfs',
-            run_without_submitting=True)
-        workflow.connect(plot_peaks, 'odf_report', ds_report_odfs, 'in_file')
-
     workflow.connect([
         (estimate_response, estimate_fod, [('wm_file', 'wm_txt'),
                                            ('gm_file', 'gm_txt'),
                                            ('csf_file', 'csf_txt')]),
-        (inputnode, resample_mask, [('t1_brain_mask', 'in_file'),
-                                    ('dwi_file', 'master')]),
         (inputnode, create_mif, [('dwi_file', 'dwi_file'),
                                  ('bval_file', 'bval_file'),
                                  ('bvec_file', 'bvec_file'),
                                  ('b_file', 'b_file')]),
-        (inputnode, plot_peaks, [('dwi_ref', 'background_image'),
-                                 ('odf_rois', 'odf_rois')]),
-        (resample_mask, plot_peaks, [('out_file', 'mask_file')]),
-        (plot_peaks, ds_report_peaks, [('peak_report', 'in_file')]),
+        (create_mif, estimate_fod, [('mif_file', 'in_file')]),
+        (inputnode, estimate_fod, [('dwi_mask', 'mask_file')]),
         (create_mif, estimate_response, [('mif_file', 'in_file')]),
         (estimate_response, outputnode, [('wm_file', 'wm_txt'),
                                          ('gm_file', 'gm_txt'),
                                          ('csf_file', 'csf_txt')]),
+        (inputnode, estimate_response, [('dwi_mask', 'in_mask')])])
 
-        (create_mif, estimate_fod, [('mif_file', 'in_file')]),
-        (resample_mask, estimate_fod, [('out_file', 'mask_file')]),
-        (resample_mask, estimate_response, [('out_file', 'in_mask')])])
 
     if not run_mtnormalize:
         workflow.connect([
@@ -200,20 +190,55 @@ A single-shell-optimized multi-tissue CSD was performed using MRtrix3Tissue
                                         ('csf_odf', 'csf_odf')])])
     else:
         intensity_norm = pe.Node(
-            MTNormalize(inlier_mask='inliers.nii.gz', norm_image='norm.nii.gz'),
-            name='intensity_norm')
+            MTNormalize(
+                nthreads=omp_nthreads,
+                inlier_mask='inliers.nii.gz', 
+                norm_image='norm.nii.gz'),
+            name='intensity_norm',
+            n_procs=omp_nthreads)
         workflow.connect([
-            (resample_mask, intensity_norm, [('out_file', 'mask_file')]),
+            (inputnode, intensity_norm, [('dwi_mask', 'mask_file')]),
             (estimate_fod, intensity_norm, [('wm_odf', 'wm_odf'),
                                             ('gm_odf', 'gm_odf'),
                                             ('csf_odf', 'csf_odf')]),
-            (intensity_norm, plot_peaks, [('wm_normed_odf', 'mif_file')]),
             (intensity_norm, outputnode, [('wm_normed_odf', 'fod_sh_mif'),
                                           ('wm_normed_odf', 'wm_odf'),
                                           ('gm_normed_odf', 'gm_odf'),
                                           ('csf_normed_odf', 'csf_odf')])])
         desc += " FODs were intensity-normalized using mtnormalize (@mtnormalize)."
 
+    if plot_reports:
+        # Make a visual report of the model
+        plot_peaks = pe.Node(
+            CLIReconPeaksReport(), 
+            name='plot_peaks',
+            n_procs=omp_nthreads)
+        ds_report_peaks = pe.Node(
+            ReconDerivativesDataSink(extension='.png',
+                                    desc="wmFOD",
+                                    suffix='peaks'),
+            name='ds_report_peaks',
+            run_without_submitting=True)
+        workflow.connect([
+            (inputnode, plot_peaks, [('dwi_ref', 'background_image'),
+                                    ('odf_rois', 'odf_rois'),
+                                    ('dwi_mask', 'mask_file')]),
+            (plot_peaks, ds_report_peaks, [('peak_report', 'in_file')])])
+
+        # Plot targeted regions
+        if available_anatomical_data['has_qsiprep_t1w_transforms']:
+            ds_report_odfs = pe.Node(
+                ReconDerivativesDataSink(extension='.png',
+                                        desc="wmFOD",
+                                        suffix='odfs'),
+                name='ds_report_odfs',
+                run_without_submitting=True)
+            workflow.connect(plot_peaks, 'odf_report', ds_report_odfs, 'in_file')
+        
+        fod_source, fod_key = (estimate_fod, "wm_odf") if not run_mtnormalize \
+            else (intensity_norm, "wm_normed_odf")
+        workflow.connect(fod_source, fod_key, plot_peaks, "mif_file")
+
     if output_suffix:
         normed = '' if not run_mtnormalize else 'mtnormed'
         ds_wm_odf = pe.Node(
@@ -326,21 +351,19 @@ def init_global_tractography_wf(omp_nthreads, available_anatomical_data, name="m
         name="outputnode")
 
     workflow = pe.Workflow(name=name)
+    plot_reports = params.pop("plot_reports", True)
+
     create_mif = pe.Node(MRTrixIngress(), name='create_mif')
 
     # Resample anat mask
-    resample_mask = pe.Node(
-        afni.Resample(outputtype='NIFTI_GZ', resample_mode="NN"), name='resample_mask')
     tck_global = pe.Node(GlobalTractography(**params), name='tck_global')
     workflow.connect([
-        (inputnode, resample_mask, [('t1_brain_mask', 'in_file'),
-                                    ('dwi_file', 'master')]),
         (inputnode, create_mif, [('dwi_file', 'dwi_file'),
                                  ('bval_file', 'bval_file'),
                                  ('bvec_file', 'bvec_file'),
                                  ('b_file', 'b_file')]),
         (create_mif, tck_global, [('mif_file', 'dwi_file')]),
-        (resample_mask, tck_global, [('out_file', 'mask')]),
+        (inputnode, tck_global, [('dwi_mask', 'mask')]),
         (inputnode, tck_global, [("wm_txt", "wm_txt"),
                                  ("gm_txt", "gm_txt"),
                                  ("csf_txt", "csf_txt")]),
@@ -421,19 +444,19 @@ def init_mrtrix_tractography_wf(omp_nthreads, available_anatomical_data, name="m
         name="outputnode")
 
     workflow = pe.Workflow(name=name)
+    plot_reports = params.pop("plot_reports", True)
     # Resample anat mask
-    resample_mask = pe.Node(
-        afni.Resample(outputtype='NIFTI_GZ', resample_mode="NN"), name='resample_mask')
     tracking_params = params.get("tckgen", {})
     tracking_params['nthreads'] = omp_nthreads
     use_sift2 = params.get("use_sift2", True)
     use_5tt = params.get("use_5tt", False)
     sift_params = params.get("sift2", {})
     sift_params['nthreads'] = omp_nthreads
-    tracking = pe.Node(TckGen(**tracking_params), name='tractography')
+    tracking = pe.Node(
+        TckGen(**tracking_params), 
+        name='tractography',
+        n_procs=omp_nthreads)
     workflow.connect([
-        (inputnode, resample_mask, [('t1_brain_mask', 'in_file'),
-                                    ('dwi_file', 'master')]),
         (inputnode, tracking, [
             ('fod_sh_mif', 'in_file'),
             ('fod_sh_mif', 'seed_dynamic')]),
@@ -451,7 +474,10 @@ def init_mrtrix_tractography_wf(omp_nthreads, available_anatomical_data, name="m
         workflow.connect(inputnode, connect_5tt, tracking, 'act_file')
 
     if use_sift2:
-        tck_sift2 = pe.Node(SIFT2(**sift_params), name="tck_sift2")
+        tck_sift2 = pe.Node(
+            SIFT2(**sift_params), 
+            name="tck_sift2",
+            n_procs=omp_nthreads)
         workflow.connect([
             (inputnode, tck_sift2, [('fod_sh_mif', 'in_fod')]),
             (tracking, tck_sift2, [('out_file', 'in_tracks')]),
@@ -503,31 +529,42 @@ def init_mrtrix_connectivity_wf(omp_nthreads, available_anatomical_data, name="m
         name="inputnode")
     outputnode = pe.Node(niu.IdentityInterface(fields=['matfile']),
                          name="outputnode")
+    plot_reports = params.pop("plot_reports", True)
     workflow = pe.Workflow(name=name)
     conmat_params = params.get("tck2connectome", {})
-    calc_connectivity = pe.Node(MRTrixAtlasGraph(tracking_params=conmat_params),
-                                name='calc_connectivity')
-    plot_connectivity = pe.Node(ConnectivityReport(), name='plot_connectivity')
-    ds_report_connectivity = pe.Node(
-        ReconDerivativesDataSink(extension='.svg',
-                                 desc="MRtrix3Connectivity",
-                                 suffix='matrices'),
-        name='ds_report_connectivity',
-        run_without_submitting=True)
+    calc_connectivity = pe.Node(
+        MRTrixAtlasGraph(tracking_params=conmat_params),
+        name='calc_connectivity',
+        n_procs=omp_nthreads)
     workflow.connect([
         (inputnode, calc_connectivity, [('atlas_configs', 'atlas_configs'),
                                         ('tck_file', 'in_file'),
                                         ('sift_weights', 'in_weights')]),
-        (calc_connectivity, plot_connectivity, [
-            ('connectivity_matfile', 'connectivity_matfile')]),
-        (plot_connectivity, ds_report_connectivity, [('out_report', 'in_file')]),
+        
         (calc_connectivity, outputnode, [('connectivity_matfile', 'matfile')])
     ])
 
+    if plot_reports:
+        plot_connectivity = pe.Node(
+            ConnectivityReport(), 
+            name='plot_connectivity',
+            n_procs=omp_nthreads)
+        ds_report_connectivity = pe.Node(
+            ReconDerivativesDataSink(extension='.svg',
+                                    desc="MRtrix3Connectivity",
+                                    suffix='matrices'),
+            name='ds_report_connectivity',
+            run_without_submitting=True)
+        workflow.connect([
+            (calc_connectivity, plot_connectivity, [
+                ('connectivity_matfile', 'connectivity_matfile')]),
+            (plot_connectivity, ds_report_connectivity, [('out_report', 'in_file')])])
+
     if output_suffix:
         # Save the output in the outputs directory
         ds_connectivity = pe.Node(ReconDerivativesDataSink(suffix=output_suffix),
                                   name='ds_' + name,
                                   run_without_submitting=True)
         workflow.connect(calc_connectivity, 'connectivity_matfile', ds_connectivity, 'in_file')
+
     return workflow
